@@ -2,6 +2,7 @@ import os
 import re
 import math
 import json
+import logging
 import argparse
 import base64
 import tqdm
@@ -23,16 +24,14 @@ from multiprocessing import Manager, Pool
 from collections import OrderedDict
 from radiomics.featureextractor import RadiomicsFeatureExtractor
 from raymics import DatasetType
-from raymics.constants import COL_LABEL, RADIOMIC_FEATURE_FILENAME, COL_INDEX,\
+from raymics.constants import COL_LABEL, RADIOMIC_FEATURE_FILENAME, COL_INDEX, \
     FILENAME_ANNOTATION, COL_DATA_PATH, COL_MASK_PATH, COL_ID
 from raymics.dataset import Dataset, LabeledDataset
 from raymics.utils import is_image, is_video, is_ndarray, is_labelme, \
     is_dicom_folder, isBase64
 from raymics.log import logger
-
-from radiomics import setVerbosity
-setVerbosity(40)
-
+from radiomics.featureextractor import logger as rlogger
+rlogger.setLevel(logging.ERROR)
 
 GROUP_LEN = 100
 
@@ -71,7 +70,6 @@ def ndarray2sitk_image(path: str) -> sitk.Image:
 def shape_to_mask(img_shape: Tuple[int, int], points: List[Tuple[float, float]],
                   shape_type: str = None, line_width: int = 10,
                   point_size: int = 5) -> np.ndarray:
-
     mask = np.zeros(img_shape[:2], dtype=np.uint8)
     mask = PIL.Image.fromarray(mask)
     draw = PIL.ImageDraw.Draw(mask)
@@ -221,7 +219,6 @@ def extract_non_ts(data_idxs: List[int],
                    mask_paths: List[str],
                    result_labels_path: str,
                    extractor: RadiomicsFeatureExtractor, lock):
-
     def read_non_ts(data_path, mask_path):
 
         # opencv image
@@ -300,7 +297,6 @@ def extract_ts(data_idx: int,
                original_labels_path: str,
                result_labels_path: str,
                lock):
-
     def read_ts():
         mask = None
         for frame in iio.imiter(data_path):
@@ -311,6 +307,7 @@ def extract_ts(data_idx: int,
                                 shape=(img.GetHeight(), img.GetWidth()))
 
             yield img, mask
+
     try:
         feature_list: List[OrderedDict] = \
             [extractor.execute(data, mask) for data, mask in read_ts()]
@@ -347,7 +344,7 @@ def extract_ts(data_idx: int,
 
 
 def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
-            processes: int = 2, progress = None) -> RadiomicsFeatureExtractor:
+            processes: int = 2, progress=None) -> RadiomicsFeatureExtractor:
     """
 
     Parameters
@@ -365,6 +362,7 @@ def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
         Processes to extracting radiomics features.
 
     """
+
     dataset = LabeledDataset(root_dir=dataset_dir)
 
     if not os.path.exists(result_dir):
@@ -372,8 +370,11 @@ def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
     else:
         result_file_list = [_ for _ in os.listdir(result_dir)
                             if not _.startswith(".") and not _.startswith("__")]
-        assert len(result_file_list) > 0, \
-            f"The result dir '{result_dir}' is not empty."
+        if len(result_file_list) > 0:
+            file_list_string = '\n- '.join([""] + result_file_list)
+            logger.error(f"The result dir '{result_dir}' is not empty with files:{file_list_string}")
+            logger.info("Please remove these files and try again!")
+            return
 
     result_labels_path = os.path.join(result_dir, FILENAME_ANNOTATION)
 
@@ -445,7 +446,7 @@ def extract(dataset_dir: str, result_dir: str, config: Union[str, dict],
         dff[feature_cols].to_csv(result_features_path, index=False)
 
     # time series
-    else:    # data_type == 1
+    else:  # data_type == 1
         result_paths = [
             os.path.join(result_dir,
                          os.path.splitext(os.path.basename(path))[0] + ".csv")
