@@ -1,4 +1,5 @@
 import os
+import base64
 import SimpleITK as sitk
 
 from typing import List, Tuple
@@ -66,6 +67,31 @@ def is_labelme(path: str) -> bool:
         return ext.lower() == "json"
 
 
+def is_dicom_folder(path: str) -> bool:
+    if not os.path.isdir(path):
+        return False
+    else:
+        dicom_paths = [p for p in get_all_files(path)
+                       if p.lower().endswith(".dcm")]
+        if dicom_paths:
+            return True
+        else:
+            return False
+
+
 def get_sitk_shape(image: sitk.Image) -> Tuple[int, int, int]:
     """Get the shape of SimpleITK image shape"""
     return image.GetWidth(), image.GetHeight(), image.GetDepth()
+
+
+def isBase64(s):
+    try:
+        if isinstance(s, str):
+            s_bytes = bytes(s, 'ascii')
+        elif isinstance(s, bytes):
+            s_bytes = s
+        else:
+            raise ValueError("Argument must be string or bytes")
+        return base64.b64encode(base64.b64decode(s_bytes)) == s_bytes
+    except Exception:
+        return False
